# Skanym GUI

This repository contains a basic GUI program made for the GeeXLab engine (LINK).
The program uses the Skanym librairy (LINK) to load and play skeletal animations.

*This is only an optional extension for Skanym and does not accomplish anything on its own.*

It allows basic control of the animation playback.
It is compatible with FBX and GLB file formats, as well as .pkl files created by the Skanym librairy.